/*
 * Copyright (C) 2023, KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Authors: wangyan <wangyan@kylinos.cn>
 *
 */

#include "common.h"
#include <QtGlobal>
#include <QDBusInterface>
#include <QDBusReply>
#include <QDebug>

namespace {

QString sessionType()
{
    return qgetenv("XDG_SESSION_TYPE");
}

}

bool env::isWayland()
{
    return sessionType() == "wayland";
}

bool env::isTabletMode()
{
    QDBusInterface interface("com.kylin.statusmanager.interface",
                             "/",
                             "com.kylin.statusmanager.interface",
                             QDBusConnection::sessionBus());
    if (!interface.isValid()) {
        qWarning() << "Can not create interface for dbus com.kylin.statusmanager.interface";
        return false;
    }

    QDBusReply<bool> result = interface.call("get_current_tabletmode");
    return result.value();
}
